@@ -36,11 +36,11 @@ namespace MediaInfoLib
 // Info
 //***************************************************************************
 
-extern const size_t Aac_sampling_frequency_Size_Usac; // USAC expands Aac_sampling_frequency[]
 extern const int32u Aac_sampling_frequency[];
 struct coreSbrFrameLengthIndex_mapping
 {
     int8u    sbrRatioIndex;
+    int16u   coreCoderFrameLength;
     int8u    outputFrameLengthDivided256;
 };
 extern const size_t coreSbrFrameLengthIndex_Mapping_Size;
@@ -50,7 +50,7 @@ extern string Aac_Channels_GetString(int8u ChannelLayout);
 extern string Aac_ChannelConfiguration_GetString(int8u ChannelLayout);
 extern string Aac_ChannelConfiguration2_GetString(int8u ChannelLayout);
 extern string Aac_ChannelLayout_GetString(const Aac_OutputChannel* const OutputChannels, size_t OutputChannels_Size);
-extern string Aac_ChannelLayout_GetString(int8u ChannelLayout, bool IsMpegh3da=false);
+extern string Aac_ChannelLayout_GetString(int8u ChannelLayout, bool IsMpegh3da=false, bool IsTip=false);
 extern string Aac_ChannelLayout_GetString(const vector<Aac_OutputChannel>& OutputChannels);
 extern string Aac_ChannelMode_GetString(int8u ChannelLayout, bool IsMpegh3da=false);
 extern string Aac_ChannelMode_GetString(const vector<Aac_OutputChannel>& OutputChannels);
@@ -357,13 +357,9 @@ void File_Mpegh3da::Streams_Fill()
     bool NoLoudnesConch;
     if (!Mpegh3da_loudnessInfo_Data[0].empty())
     {
+        C.Reset(false, true);
         C.loudnessInfo_Data[0]=Mpegh3da_loudnessInfo_Data[0].begin()->second.Data[0];
         C.loudnessInfo_Data[1]=Mpegh3da_loudnessInfo_Data[0].begin()->second.Data[1];
-        #if MEDIAINFO_CONFORMANCE
-            C.loudnessInfoSet_Present[0]=0;
-            C.loudnessInfoSet_Present[1]=1;
-        #endif
-        C.loudnessInfoSet_IsNotValid=false;
         Fill_Loudness(NULL);
         C.loudnessInfo_Data[0].clear();
         C.loudnessInfo_Data[1].clear();
@@ -411,12 +407,8 @@ void File_Mpegh3da::Streams_Fill()
             std::map<int8u, loudness_info_data>::iterator Loudness=Mpegh3da_loudnessInfo_Data[3].find(P.ID);
             if (Loudness!=Mpegh3da_loudnessInfo_Data[3].end())
             {
+                C.Reset(false, true);
                 C.loudnessInfo_Data[0]=Loudness->second.Data[0];
-                #if MEDIAINFO_CONFORMANCE
-                    C.loudnessInfoSet_Present[0]=0;
-                    C.loudnessInfoSet_Present[1]=1;
-                #endif
-                C.loudnessInfoSet_IsNotValid=false;
                 Fill_Loudness(p.c_str(), NoLoudnesConch);
                 C.loudnessInfo_Data[0].clear();
             }
@@ -546,12 +538,8 @@ void File_Mpegh3da::Streams_Fill()
             std::map<int8u, loudness_info_data>::iterator Loudness=Mpegh3da_loudnessInfo_Data[1].find(G.ID);
             if (Loudness!=Mpegh3da_loudnessInfo_Data[1].end())
             {
+                C.Reset(false, true);
                 C.loudnessInfo_Data[0]=Loudness->second.Data[0];
-                #if MEDIAINFO_CONFORMANCE
-                    C.loudnessInfoSet_Present[0]=0;
-                    C.loudnessInfoSet_Present[1]=1;
-                #endif
-                C.loudnessInfoSet_IsNotValid=false;
                 Fill_Loudness(g.c_str(), NoLoudnesConch);
                 C.loudnessInfo_Data[0].clear();
             }
@@ -571,12 +559,8 @@ void File_Mpegh3da::Streams_Fill()
             std::map<int8u, loudness_info_data>::iterator Loudness=Mpegh3da_loudnessInfo_Data[2].find(G.ID);
             if (Loudness!=Mpegh3da_loudnessInfo_Data[2].end())
             {
+                C.Reset(false, true);
                 C.loudnessInfo_Data[0]=Loudness->second.Data[0];
-                #if MEDIAINFO_CONFORMANCE
-                    C.loudnessInfoSet_Present[0]=0;
-                    C.loudnessInfoSet_Present[1]=1;
-                #endif
-                C.loudnessInfoSet_IsNotValid=false;
                 Fill_Loudness(g.c_str(), NoLoudnesConch);
                 C.loudnessInfo_Data[0].clear();
             }
