@@ -31,6 +31,9 @@
 #if defined(MEDIAINFO_AC4_YES)
     #include "MediaInfo/Audio/File_Ac4.h"
 #endif
+#if defined(MEDIAINFO_ADM_YES)
+    #include "MediaInfo/Audio/File_Adm.h"
+#endif
 #if defined(MEDIAINFO_DOLBYE_YES)
     #include "MediaInfo/Audio/File_DolbyE.h"
 #endif
@@ -43,6 +46,9 @@
 #if MEDIAINFO_SEEK
     #include "MediaInfo/MediaInfo_Internal.h"
 #endif // MEDIAINFO_SEEK
+#if defined(MEDIAINFO_ADM_YES)
+    #include <zlib.h>
+#endif
 #include "MediaInfo/File_Unknown.h"
 #include "MediaInfo/MediaInfo_Config_MediaInfo.h"
 //---------------------------------------------------------------------------
@@ -55,7 +61,7 @@ namespace MediaInfoLib
 //***************************************************************************
 
 //---------------------------------------------------------------------------
-static const char* Smpte_St0337_data_type[32]= // SMPTE ST 338
+static const char* Smpte_St0337_data_type[]= // SMPTE ST 338
 {
     "",
     "AC-3",
@@ -74,25 +80,26 @@ static const char* Smpte_St0337_data_type[32]= // SMPTE ST 338
     "",
     "",
     "E-AC-3",
-    "",
-    "",
+    "DTS",
+    "WMA",
+    "AAC",
     "AAC",
-    "",
     "E-AC-3",
     "",
     "",
-    "",
-    "",
+    "AC-4",
+    "MPEG-H 3D Audio",
     "Utility",
     "KLV",
     "Dolby E",
     "Captioning",
     "User defined",
-    "",
+    "Extended",
+    "ADM",
 };
 
 //---------------------------------------------------------------------------
-static stream_t Smpte_St0337_data_type_StreamKind[32]= // SMPTE 338M
+static stream_t Smpte_St0337_data_type_StreamKind[sizeof(Smpte_St0337_data_type)/sizeof(char*)]= // SMPTE 338M
 {
     Stream_Max,
     Stream_Audio,
@@ -126,15 +133,31 @@ static stream_t Smpte_St0337_data_type_StreamKind[32]= // SMPTE 338M
     Stream_Text,
     Stream_Max,
     Stream_Max,
+    Stream_Audio,
 };
 
+#if defined(MEDIAINFO_ADM_YES)
+static const char* Smpte_St0337_Adm_multiple_chunk_flag[4]=
+{
+    "Full",
+    "First",
+    "Intermediate",
+    "Last",
+};
+static const char* Smpte_St0337_Adm_format_type[2]=
+{
+    "UTF-8",
+    "UTF-8 gzip",
+};
+#endif
+
 //***************************************************************************
 // Constructor/Destructor
 //***************************************************************************
 
 //---------------------------------------------------------------------------
 File_SmpteSt0337::File_SmpteSt0337()
-:File__Analyze()
+:File_Pcm_Base()
 {
     // Configuration
     #if MEDIAINFO_EVENTS
@@ -152,7 +175,7 @@ File_SmpteSt0337::File_SmpteSt0337()
     // Temp
     FrameRate=0;
     Stream_Bits=0;
-    data_type=(int8u)-1;
+    data_type=(int32u)-1;
     GuardBand_Before=0;
     GuardBand_After=0;
     NullPadding_Size=0;
@@ -198,7 +221,7 @@ void File_SmpteSt0337::Streams_Fill()
                 FrameRate=FrameRate_Int/1.001;
         }
     }
-    else if (data_type!=(int8u)-1)
+    else if (data_type<sizeof(Smpte_St0337_data_type_StreamKind)/sizeof(stream_t))
     {
         if (Retrieve(Stream_Audio, 0, Audio_Format).empty() && Smpte_St0337_data_type_StreamKind[data_type]!=Stream_Max)
         {
@@ -262,28 +285,36 @@ void File_SmpteSt0337::Streams_Fill()
 
     for (size_t Pos=0; Pos<Count_Get(StreamKind_Last); Pos++)
     {
-        if (Endianness=='L' && Retrieve(StreamKind_Last, Pos, "Format_Settings_Endianness")==__T("Little"))
-            Endianness='B';
-        switch (Endianness)
+        if (!IsSub || Retrieve_Const(StreamKind_Last, Pos, "Metadata_MuxingMode").empty())
         {
-            case 'B' :
-                        Fill(StreamKind_Last, Pos, "Format_Settings", "Big");
-                        Fill(StreamKind_Last, Pos, "Format_Settings_Endianness", "Big", Unlimited, true, true);
-                        break;
-            case 'L' :
-                        Fill(StreamKind_Last, Pos, "Format_Settings", "Little");
-                        Fill(StreamKind_Last, Pos, "Format_Settings_Endianness", "Little", Unlimited, true, true);
-                        break;
-            default  : ;
+            if (!IsSub && StreamKind_Last==Stream_Audio && Retrieve_Const(StreamKind_Last, Pos, "Format").empty())
+            {
+                Fill(Stream_Audio, Pos, Audio_Format, "PCM");
+                Fill(Stream_Audio, Pos, Audio_Channel_s_, 2);
+            }
+            if (Endianness=='L' && Retrieve(StreamKind_Last, Pos, "Format_Settings_Endianness")==__T("Little"))
+                Endianness='B';
+            switch (Endianness)
+            {
+                case 'B' :
+                            Fill(StreamKind_Last, Pos, "Format_Settings", "Big");
+                            Fill(StreamKind_Last, Pos, "Format_Settings_Endianness", "Big", Unlimited, true, true);
+                            break;
+                case 'L' :
+                            Fill(StreamKind_Last, Pos, "Format_Settings", "Little");
+                            Fill(StreamKind_Last, Pos, "Format_Settings_Endianness", "Little", Unlimited, true, true);
+                            break;
+                default  : ;
+            }
+            Fill(StreamKind_Last, Pos, "Format_Settings_Mode", Container_Bits);
+            if (Retrieve(StreamKind_Last, Pos, Fill_Parameter(StreamKind_Last, Generic_BitDepth)).empty())
+                Fill(StreamKind_Last, Pos, Fill_Parameter(StreamKind_Last, Generic_BitDepth), Stream_Bits);
+            if (Retrieve(StreamKind_Last, Pos, Fill_Parameter(StreamKind_Last, Generic_BitRate_Mode))!=__T("CBR"))
+                Fill(StreamKind_Last, Pos, Fill_Parameter(StreamKind_Last, Generic_BitRate_Mode), "CBR");
         }
-        Fill(StreamKind_Last, Pos, "Format_Settings_Mode", Container_Bits);
-        if (Retrieve(StreamKind_Last, Pos, Fill_Parameter(StreamKind_Last, Generic_BitDepth)).empty())
-            Fill(StreamKind_Last, Pos, Fill_Parameter(StreamKind_Last, Generic_BitDepth), Stream_Bits);
 
-        if (IsSub)
+        if (IsSub && Retrieve_Const(StreamKind_Last, Pos, "Metadata_MuxingMode").empty())
             Fill(StreamKind_Last, Pos, "MuxingMode", "SMPTE ST 337");
-        if (Retrieve(StreamKind_Last, Pos, Fill_Parameter(StreamKind_Last, Generic_BitRate_Mode))!=__T("CBR"))
-            Fill(StreamKind_Last, Pos, Fill_Parameter(StreamKind_Last, Generic_BitRate_Mode), "CBR");
     }
 }
 
@@ -1215,23 +1246,153 @@ void File_SmpteSt0337::Data_Parse()
 
     // Parsing
     int32u  length_code;
-    int8u data_type_New;
+    int8u data_stream_number;
+    int32u data_type_New;
+    int8u data_type_dependent;
+    int8u* UncompressedData=NULL;
+    size_t UncompressedData_Size=0;
+    string MuxingMode;
     Element_Begin1("Header");
         BS_Begin();
         Skip_S3(Stream_Bits,                                    "Pa");
         Skip_S3(Stream_Bits,                                    "Pb");
         Element_Begin1("Pc");
-            Skip_S1( 3,                                         "data_stream_number");
-            Skip_S1( 5,                                         "data_type_dependent");
+            Get_S1 ( 3, data_stream_number,                     "data_stream_number");
+            Get_S1 ( 5, data_type_dependent,                    "data_type_dependent");
             Skip_SB(                                            "error_flag");
             Info_S1( 2, data_mode,                              "data_mode"); Param_Info2(16+4*data_mode, " bits");
-            Get_S1 ( 5, data_type_New,                          "data_type"); Param_Info1(Smpte_St0337_data_type[data_type_New]);
+            Get_S4 ( 5, data_type_New,                          "data_type"); Param_Info1(Smpte_St0337_data_type[data_type_New]);
             if (Stream_Bits>16)
-                Skip_S1( 4,                                     "reserved");
-            if (Stream_Bits>20)
-                Skip_S1( 4,                                     "reserved");
+                Skip_S1(Stream_Bits-16,                         "reserved");
         Element_End0();
         Get_S3 (Stream_Bits, length_code,                       "length_code"); Param_Info2(length_code/8, " bytes");
+        if (data_type_New==31)
+        {
+            if (Stream_Bits>16)
+                Skip_S1(Stream_Bits-16,                         "reserved");
+            Get_S4 (16, data_type_New,                          "data_type");
+            data_type_New+=32;
+            Skip_S3(Stream_Bits,                                "reserved");
+            if (data_type_New==32+1) // ADM
+            {
+                int8u multiple_chunk_flag=data_type_dependent>>3;               //2-bit
+                bool format_flag=((data_type_dependent>>2)&1)?true:false;       //1-bit
+                bool assemble_flag=((data_type_dependent>>1)&1)?true:false;     //1-bit
+                bool changedMetadata_flag=(data_type_dependent&1)?true:false;   //1-bit
+                Param_Info1(Smpte_St0337_Adm_multiple_chunk_flag[multiple_chunk_flag]);
+                int8u format_type=0, Track_ID=0, track_numbers=0, in_timeline_flag=0;
+                if (format_flag)
+                {
+                    Element_Begin1("format_info");
+                    Skip_S2(12,                                 "reserved");
+                    Get_S1 (4, format_type,                     "format_type"); Param_Info1C(format_type<sizeof(Smpte_St0337_Adm_format_type)/sizeof(const char*), Smpte_St0337_Adm_format_type[format_type]);
+                    if (Stream_Bits>16)
+                        Skip_S1(Stream_Bits-16,                 "reserved");
+                }
+                if (assemble_flag)
+                {
+                    Element_Begin1("assemble_info");
+                    Skip_S2(2,                                  "reserved");
+                    Get_S1 (6, Track_ID,                        "Track_ID");
+                    Get_S1 (6, track_numbers,                   "track_numbers");
+                    Get_S1 (2, in_timeline_flag,                "in_timeline_flag"); Param_Info1(Smpte_St0337_Adm_multiple_chunk_flag[in_timeline_flag]);
+                    if (Stream_Bits>16)
+                        Skip_S1(Stream_Bits-16,                 "reserved");
+                    Element_End0();
+                }
+                MuxingMode=string("SMPTE ST 337 / SMPTE ST 2116");
+                if (!data_stream_number && !multiple_chunk_flag && !in_timeline_flag && format_type<=1)
+                {
+                    MuxingMode+=" Level ";
+                    MuxingMode+='A';
+                    if (format_type==1)
+                        MuxingMode+='X';
+                    if (track_numbers<10)
+                        MuxingMode+='1'+track_numbers;
+                    else
+                    {
+                        MuxingMode+='1';
+                        MuxingMode+='0'-10+track_numbers;
+                    }
+                }
+                if (Parser || data_stream_number || multiple_chunk_flag || in_timeline_flag || format_type>1 || Track_ID || track_numbers)
+                {
+                    Skip_BS(Data_BS_Remain(),                   "Data (Unsupported)");
+                }
+                else if (format_type==1)
+                {
+                    int8u* Compressed=new int8u[Data_BS_Remain()/8];
+                    size_t Compressed_Offset=0;
+                    while (Data_BS_Remain())
+                    {
+                        int64u Data;
+                        Get_S6(Stream_Bits*2, Data, "Data");
+                        for (int8u i=0; i<Stream_Bits/4; i++)
+                        {
+                            Compressed[Compressed_Offset++]=(int8u)(Data>>((Stream_Bits/4-i-1)*8));
+                        }
+                    }
+                    BS_End();
+
+                    // Adapting
+                    const int8u* Save_Buffer=Buffer;
+                    size_t Save_Buffer_Offset=Buffer_Offset;
+                    size_t Save_Buffer_Size=Buffer_Size;
+                    int64u Save_Element_Size=Element_Size;
+                    Buffer=Compressed;
+                    Buffer_Offset=0;
+                    Buffer_Size=Compressed_Offset;
+                    Element_Offset=0;
+                    Element_Size=Buffer_Size;
+
+                    //Uncompress init
+                    z_stream strm;
+                    strm.next_in=(Bytef*)Compressed;;
+                    strm.avail_in=Compressed_Offset;
+                    strm.next_out=NULL;
+                    strm.avail_out=0;
+                    strm.total_out=0;
+                    strm.zalloc=Z_NULL;
+                    strm.zfree=Z_NULL;
+                    inflateInit2(&strm, 15+16); // 15 + 16 are magic values for gzip
+
+                    //Prepare out
+                    strm.avail_out=0x10000; //Blocks of 64 KiB, arbitrary chosen, as a begin
+                    strm.next_out=(Bytef*)new Bytef[strm.avail_out];
+
+                    //Parse compressed data, with handling of the case the output buffer is not big enough
+                    for (;;)
+                    {
+                        //inflate
+                        int inflate_Result=inflate(&strm, Z_NO_FLUSH);
+                        if (inflate_Result<0)
+                            break;
+
+                        //Check if we need to stop
+                        if (strm.avail_out || inflate_Result)
+                            break;
+
+                        //Need to increase buffer
+                        size_t UncompressedData_NewMaxSize=strm.total_out*4;
+                        int8u* UncompressedData_New=new int8u[UncompressedData_NewMaxSize];
+                        memcpy(UncompressedData_New, strm.next_out-strm.total_out, strm.total_out);
+                        delete[] strm.next_out; strm.next_out=UncompressedData_New;
+                        strm.next_out=strm.next_out+strm.total_out;
+                        strm.avail_out=UncompressedData_NewMaxSize-strm.total_out;
+                    }
+                    UncompressedData=strm.next_out-strm.total_out;
+                    UncompressedData_Size=strm.total_out;
+
+                    // Adapting
+                    Buffer=Save_Buffer;
+                    Buffer_Offset=Save_Buffer_Offset;
+                    Buffer_Size=Save_Buffer_Size;
+                    Element_Offset=Save_Element_Size;
+                    Element_Size=Save_Element_Size;
+                }
+                Element_End0();
+            }
+        }
         BS_End();
     Element_End0();
 
@@ -1314,6 +1475,38 @@ void File_SmpteSt0337::Data_Parse()
                         }
                         #endif
                         break;
+            case 32+1 : // ADM
+                        #if defined(MEDIAINFO_ADM_YES)
+                        {
+                        if (UncompressedData || Element_Offset<Element_Size)
+                        {
+                            Parser=new File_Adm();
+                            ((File_Adm*)Parser)->MuxingMode=MuxingMode;
+                        }
+                        else
+                        {
+                            //Unsupported features are present
+                            Parser=new File_Unknown();
+                            Open_Buffer_Init(Parser);
+                            Parser->Accept();
+                            Parser->Stream_Prepare(Stream_Audio);
+                            Parser->Fill(Stream_Audio, 0, "Metadata_Format", "ADM");
+                            Parser->Fill(Stream_Audio, 0, "Metadata_MuxingMode", MuxingMode);
+                            Parser->Finish();
+                        }
+                        #else
+                        {
+                            //Filling
+                            Parser=new File_Unknown();
+                            Open_Buffer_Init(Parser);
+                            Parser->Accept();
+                            Parser->Stream_Prepare(Stream_Audio);
+                            Parser->Fill(Stream_Audio, 0, "Metadata_Format", "ADM");
+                            Parser->Finish();
+                        }
+                        #endif
+                        }
+                        break;
             default : ;
         }
 
@@ -1402,7 +1595,17 @@ void File_SmpteSt0337::Data_Parse()
         #endif
 
         Parser->FrameInfo=FrameInfo;
-        Open_Buffer_Continue(Parser, Buffer+Buffer_Offset+(size_t)Element_Offset, (size_t)(Element_Size-Element_Offset-Padding/8));
+        if (UncompressedData)
+        {
+            Open_Buffer_Continue(Parser, UncompressedData, UncompressedData_Size);
+            delete[] UncompressedData;
+        }
+        else            
+        {
+            int64u Element_Size_Temp=Element_Size-Padding/8;
+            if (Element_Offset<Element_Size_Temp)
+                Open_Buffer_Continue(Parser, Buffer+Buffer_Offset+(size_t)Element_Offset, (size_t)(Element_Size_Temp-Element_Offset));
+        }
         Element_Offset=Element_Size;
         #if MEDIAINFO_DEMUX
             FrameInfo.DUR=Parser->FrameInfo.DUR;
