@@ -1051,26 +1051,15 @@ void File__Analyze::Get_EB(int64u &Info, const char* Name)
         Size++;
         Peek_BS(Size, Size_Mark);
     }
+    BS_End();
 
     //Integrity
-    if (!BS->Remain() || Size>8)
+    if (!Size_Mark || Size>8)
     {
-        if (Size>8)
-        {
-            //Element[Element_Level].IsComplete=true; //If it is in a header
-            Trusted_IsNot("EBML integer parsing error");
-        }
+        Trusted_IsNot("EBML integer parsing error");
         Info=0;
         return;
     }
-    BS_End();
-    if (File_Offset+Buffer_Offset+Element_Offset>=Element[Element_Level].Next)
-    {
-        //Element[Element_Level].IsComplete=true; //If it is in a header
-        Trusted_IsNot("Not enough place to have an EBML");
-        Info=0;
-        return; //Not enough space
-    }
     INTEGRITY_SIZE_ATLEAST_INT(Size);
 
     //Element Name
@@ -1143,26 +1132,16 @@ void File__Analyze::Get_ES(int64s &Info, const char* Name)
         Size++;
         Peek_BS(Size, Size_Mark);
     }
+    size_t Remain=BS->Remain();
+    BS_End();
 
     //Integrity
-    if (!BS->Remain() || Size>8)
+    if (!Size_Mark || Size>8)
     {
-        if (Size>8)
-        {
-            //Element[Element_Level].IsComplete=true; //If it is in a header
-            Trusted_IsNot("EBML integer parsing error");
-        }
+        Trusted_IsNot("EBML integer parsing error");
         Info=0;
         return;
     }
-    BS_End();
-    if (File_Offset+Buffer_Offset+Element_Offset>=Element[Element_Level].Next)
-    {
-        //Element[Element_Level].IsComplete=true; //If it is in a header
-        Trusted_IsNot("Not enough place to have an EBML");
-        Info=0;
-        return; //Not enough space
-    }
     INTEGRITY_SIZE_ATLEAST_INT(Size);
 
     //Element Name
@@ -1242,21 +1221,16 @@ void File__Analyze::Get_VS(int64u &Info, const char* Name)
         Info=128*Info+BS->Get1(7);
     }
     while (more_data && Size<=8 && BS->Remain());
+    size_t Remain=BS->Remain();
     BS_End();
 
     //Integrity
-    if (Size>8)
+    if (more_data || Size>8)
     {
         Trusted_IsNot("Variable Size Value parsing error");
         Info=0;
         return;
     }
-    if (File_Offset+Buffer_Offset+Element_Offset>=Element[Element_Level].Next)
-    {
-        Trusted_IsNot("Not enough place to have a Variable Size Value");
-        Info=0;
-        return; //Not enough space
-    }
 
     if (Trace_Activated)
     {
@@ -1285,18 +1259,12 @@ void File__Analyze::Skip_VS(const char* Name)
     BS_End();
 
     //Integrity
-    if (Size>8)
+    if (more_data || Size>8)
     {
         Trusted_IsNot("Variable Size Value parsing error");
         Info=0;
         return;
     }
-    if (File_Offset+Buffer_Offset+Element_Offset>=Element[Element_Level].Next)
-    {
-        Trusted_IsNot("Not enough place to have a Variable Size Value");
-        Info=0;
-        return; //Not enough space
-    }
 
     if (Trace_Activated)
     {
