@@ -40,6 +40,7 @@
     #include <fstream>
     #endif //WINDOWS
 #endif //MEDIAINFO_FIXITY
+#include <algorithm>
 using namespace ZenLib;
 //---------------------------------------------------------------------------
 
@@ -1212,6 +1213,51 @@ void File__Analyze::Streams_Finish_StreamOnly_Audio(size_t Pos)
         }
     }
 
+    //ChannelLayout
+    if (Retrieve_Const(Stream_Audio, Pos, Audio_ChannelLayout).empty())
+    {
+        ZtringList ChannelLayout_List;
+        ChannelLayout_List.Separator_Set(0, __T(" "));
+        ChannelLayout_List.Write(Retrieve_Const(Stream_Audio, Pos, Audio_ChannelLayout));
+        size_t ChannelLayout_List_SizeBefore=ChannelLayout_List.size();
+        
+        size_t NumberOfSubstreams=(size_t)Retrieve_Const(Stream_Audio, Pos, "NumberOfSubstreams").To_int64u();
+        for (size_t i=0; i<NumberOfSubstreams; i++)
+        {
+            static const char* const Places[]={ "ChannelLayout", "BedChannelConfiguration" };
+            static constexpr size_t Places_Size=sizeof(Places)/sizeof(decltype(*Places));
+            for (const auto Place : Places)
+            {
+                ZtringList AdditionaChannelLayout_List;
+                AdditionaChannelLayout_List.Separator_Set(0, __T(" "));
+                AdditionaChannelLayout_List.Write(Retrieve_Const(Stream_Audio, Pos, ("Substream"+std::to_string(i)+' '+Place).c_str()));
+                for (auto& AdditionaChannelLayout_Item: AdditionaChannelLayout_List)
+                {
+                    if (std::find(ChannelLayout_List.cbegin(), ChannelLayout_List.cend(), AdditionaChannelLayout_Item)==ChannelLayout_List.cend())
+                        ChannelLayout_List.push_back(std::move(AdditionaChannelLayout_Item));
+                }
+            }
+        }
+        if (ChannelLayout_List.size()!=ChannelLayout_List_SizeBefore)
+        {
+            Fill(Stream_Audio, Pos, Audio_Channel_s_, ChannelLayout_List.size(), 10, true);
+            Clear(Stream_Audio, Pos, Audio_ChannelPositions);
+            Fill(Stream_Audio, Pos, Audio_ChannelLayout, ChannelLayout_List.Read(), true);
+        }
+    }
+
+    //Channel(s)
+    if (Retrieve_Const(Stream_Audio, Pos, Audio_Channel_s_).empty())
+    {
+        size_t NumberOfSubstreams=(size_t)Retrieve_Const(Stream_Audio, Pos, "NumberOfSubstreams").To_int64u();
+        if (NumberOfSubstreams==1)
+        {
+            auto Channels=Retrieve_Const(Stream_Audio, Pos, "Substream0 Channel(s)").To_int32u();
+            if (Channels)
+                Fill(Stream_Audio, Pos, Audio_Channel_s_, Channels);
+        }
+    }
+
     //Duration
     if (Retrieve(Stream_Audio, Pos, Audio_Duration).empty())
     {
@@ -1709,17 +1755,17 @@ void File__Analyze::Streams_Finish_HumanReadable_PerStream(stream_t StreamKind,
     //Format_Settings_Matrix
     if (StreamKind==Stream_Video && Parameter==Video_Format_Settings_Matrix)
     {
-        Fill(Stream_Video, StreamPos, Video_Format_Settings_Matrix_String, MediaInfoLib::Config.Language_Get_Translate(__T("Format_Settings_Matrix_"), Value));
+        Fill(Stream_Video, StreamPos, Video_Format_Settings_Matrix_String, MediaInfoLib::Config.Language_Get_Translate(__T("Format_Settings_Matrix_"), Value), true);
     }
 
     //Scan type
     if (StreamKind==Stream_Video && Parameter==Video_ScanType)
     {
-        Fill(Stream_Video, StreamPos, Video_ScanType_String, MediaInfoLib::Config.Language_Get_Translate(__T("Interlaced_"), Value));
+        Fill(Stream_Video, StreamPos, Video_ScanType_String, MediaInfoLib::Config.Language_Get_Translate(__T("Interlaced_"), Value), true);
     }
     if (StreamKind==Stream_Video && Parameter==Video_ScanType_Original)
     {
-        Fill(Stream_Video, StreamPos, Video_ScanType_Original_String, MediaInfoLib::Config.Language_Get_Translate(__T("Interlaced_"), Value));
+        Fill(Stream_Video, StreamPos, Video_ScanType_Original_String, MediaInfoLib::Config.Language_Get_Translate(__T("Interlaced_"), Value), true);
     }
     if (StreamKind==Stream_Video && Parameter==Video_ScanType_StoreMethod)
     {
@@ -1727,21 +1773,21 @@ void File__Analyze::Streams_Finish_HumanReadable_PerStream(stream_t StreamKind,
         if (!Retrieve(Stream_Video, StreamPos, Video_ScanType_StoreMethod_FieldsPerBlock).empty())
             ToTranslate+=__T('_')+Retrieve(Stream_Video, StreamPos, Video_ScanType_StoreMethod_FieldsPerBlock);
         Ztring Translated=MediaInfoLib::Config.Language_Get(ToTranslate);
-        Fill(Stream_Video, StreamPos, Video_ScanType_StoreMethod_String, Translated.find(__T("StoreMethod_"))?Translated:Value);
+        Fill(Stream_Video, StreamPos, Video_ScanType_StoreMethod_String, Translated.find(__T("StoreMethod_"))?Translated:Value, true);
     }
 
     //Scan order
     if (StreamKind==Stream_Video && Parameter==Video_ScanOrder)
     {
-        Fill(Stream_Video, StreamPos, Video_ScanOrder_String, MediaInfoLib::Config.Language_Get_Translate(__T("Interlaced_"), Value));
+        Fill(Stream_Video, StreamPos, Video_ScanOrder_String, MediaInfoLib::Config.Language_Get_Translate(__T("Interlaced_"), Value), true);
     }
     if (StreamKind==Stream_Video && Parameter==Video_ScanOrder_Stored)
     {
-        Fill(Stream_Video, StreamPos, Video_ScanOrder_Stored_String, MediaInfoLib::Config.Language_Get_Translate(__T("Interlaced_"), Value));
+        Fill(Stream_Video, StreamPos, Video_ScanOrder_Stored_String, MediaInfoLib::Config.Language_Get_Translate(__T("Interlaced_"), Value), true);
     }
     if (StreamKind==Stream_Video && Parameter==Video_ScanOrder_Original)
     {
-        Fill(Stream_Video, StreamPos, Video_ScanOrder_Original_String, MediaInfoLib::Config.Language_Get_Translate(__T("Interlaced_"), Value));
+        Fill(Stream_Video, StreamPos, Video_ScanOrder_Original_String, MediaInfoLib::Config.Language_Get_Translate(__T("Interlaced_"), Value), true);
     }
 
     //Interlacement
@@ -1759,19 +1805,19 @@ void File__Analyze::Streams_Finish_HumanReadable_PerStream(stream_t StreamKind,
     //FrameRate_Mode
     if (StreamKind==Stream_Video && Parameter==Video_FrameRate_Mode)
     {
-        Fill(Stream_Video, StreamPos, Video_FrameRate_Mode_String, MediaInfoLib::Config.Language_Get_Translate(__T("FrameRate_Mode_"), Value));
+        Fill(Stream_Video, StreamPos, Video_FrameRate_Mode_String, MediaInfoLib::Config.Language_Get_Translate(__T("FrameRate_Mode_"), Value), true);
     }
 
     //Compression_Mode
     if (Parameter==Fill_Parameter(StreamKind, Generic_Compression_Mode))
     {
-        Fill(StreamKind, StreamPos, Fill_Parameter(StreamKind, Generic_Compression_Mode_String), MediaInfoLib::Config.Language_Get_Translate(__T("Compression_Mode_"), Value));
+        Fill(StreamKind, StreamPos, Fill_Parameter(StreamKind, Generic_Compression_Mode_String), MediaInfoLib::Config.Language_Get_Translate(__T("Compression_Mode_"), Value), true);
     }
 
     //Delay_Source
     if (Parameter==Fill_Parameter(StreamKind, Generic_Delay_Source))
     {
-        Fill(StreamKind, StreamPos, Fill_Parameter(StreamKind, Generic_Delay_Source_String), MediaInfoLib::Config.Language_Get_Translate(__T("Delay_Source_"), Value));
+        Fill(StreamKind, StreamPos, Fill_Parameter(StreamKind, Generic_Delay_Source_String), MediaInfoLib::Config.Language_Get_Translate(__T("Delay_Source_"), Value), true);
     }
 
     //Gop_OpenClosed
