@@ -67,6 +67,7 @@ Ztring Xml_Name_Escape_0_7_78 (const Ztring &Name)
 {
     Ztring ToReturn(Name);
     ToReturn.FindAndReplace(__T(" "), __T("_"), 0, Ztring_Recursive);
+    ToReturn.FindAndReplace(__T("-"), Ztring(), 0, Ztring_Recursive);
     ToReturn.FindAndReplace(__T("/"), __T("_"), 0, Ztring_Recursive);
     ToReturn.FindAndReplace(__T("("), Ztring(), 0, Ztring_Recursive);
     ToReturn.FindAndReplace(__T(")"), Ztring(), 0, Ztring_Recursive);
@@ -81,7 +82,6 @@ Ztring Xml_Name_Escape_0_7_78 (const Ztring &Name)
         if (!(ToReturn[ToReturn_Pos]>=__T('A') && ToReturn[ToReturn_Pos]<=__T('Z'))
          && !(ToReturn[ToReturn_Pos]>=__T('a') && ToReturn[ToReturn_Pos]<=__T('z'))
          && !(ToReturn[ToReturn_Pos]>=__T('0') && ToReturn[ToReturn_Pos]<=__T('9'))
-         && !(ToReturn[ToReturn_Pos]==__T('-')) // Authorized if not first pos
          && !(ToReturn[ToReturn_Pos]==__T('_')))
             ToReturn.erase(ToReturn_Pos, 1);
         else
@@ -149,6 +149,42 @@ Ztring MediaInfo_Internal::Inform()
         }
     #endif //MEDIAINFO_TRACE
 
+    #if MEDIAINFO_ADVANCED
+        if (Config.TimeCode_Dumps)
+        {
+            string Result="<media";
+            if (Config.ParseSpeed<1.0)
+                Result+=" full=\"0\"";
+            Ztring Options=Get(Stream_General, 0, General_CompleteName, Info_Options);
+            if (InfoOption_ShowInInform<Options.size() && Options[InfoOption_ShowInInform]==__T('Y'))
+            {
+                Result+=" ref=\"";
+                Result+=XML_Encode(Get(Stream_General, 0, General_CompleteName)).To_UTF8();
+                Result+='\"';
+            }
+            Result+=" format=\"";
+            Result+=XML_Encode(Get(Stream_General, 0, General_Format)).To_UTF8();
+            Result+="\">\n";
+            for (const auto& TimeCode_Dump : *Config.TimeCode_Dumps)
+            {
+                Result+="  <timecode_stream";
+                Result+=TimeCode_Dump.second.Attributes_First;
+                Result+=" frame_count=\""+std::to_string(TimeCode_Dump.second.FrameCount)+'\"';
+                Result+=TimeCode_Dump.second.Attributes_Last;
+                if (TimeCode_Dump.second.List.empty())
+                    Result+="/>\n";
+                else
+                {
+                    Result+=">\n";
+                    Result+=TimeCode_Dump.second.List;
+                    Result+="  </timecode_stream>\n";
+                }
+            }
+            Result+="</media>";
+            return Ztring().From_UTF8(Result);
+        }
+    #endif //MEDIAINFO_ADVANCED
+
     #if defined(MEDIAINFO_EBUCORE_YES)
         if (MediaInfoLib::Config.Inform_Get()==__T("EBUCore_1.5"))
             return Export_EbuCore().Transform(*this, Export_EbuCore::Version_1_5, Export_EbuCore::AcquisitionDataOutputMode_Default,
@@ -200,6 +236,12 @@ Ztring MediaInfo_Internal::Inform()
     #if defined(MEDIAINFO_MPEG7_YES)
         if (MediaInfoLib::Config.Inform_Get()==__T("MPEG-7"))
             return Export_Mpeg7().Transform(*this);
+        if (MediaInfoLib::Config.Inform_Get()==__T("MPEG-7_Strict"))
+            return Export_Mpeg7().Transform(*this, 0);
+        if (MediaInfoLib::Config.Inform_Get()==__T("MPEG-7_Relaxed"))
+            return Export_Mpeg7().Transform(*this, 1);
+        if (MediaInfoLib::Config.Inform_Get()==__T("MPEG-7_Extended"))
+            return Export_Mpeg7().Transform(*this, 2);
     #endif //defined(MEDIAINFO_MPEG7_YES)
     #if defined(MEDIAINFO_PBCORE_YES)
         if (MediaInfoLib::Config.Inform_Get()==__T("PBCore_1") || MediaInfoLib::Config.Inform_Get()==__T("PBCore1")) // 1.x
