@@ -458,6 +458,8 @@ void File_Ancillary::Read_Buffer_AfterParsing()
     Frame_Count_InThisBlock++;
     if (Frame_Count_NotParsedIncluded!=(int64u)-1)
         Frame_Count_NotParsedIncluded++;
+    if (!Status[IsFilled] && Config->ParseSpeed<=0)
+        Fill();
 }
 
 //---------------------------------------------------------------------------
@@ -680,7 +682,8 @@ void File_Ancillary::Data_Parse()
                                         if (!Rdd18_Parser->Status[IsFinished])
                                         {
                                             Rdd18_Parser->Frame_Count=Frame_Count;
-                                            Open_Buffer_Continue(Rdd18_Parser, Payload+1, (size_t)DataCount-1);
+                                            if (DataCount)
+                                                Open_Buffer_Continue(Rdd18_Parser, Payload+1, (size_t)DataCount-1);
                                         }
                                         #endif //defined(MEDIAINFO_MXF_YES)
                                         break;
