@@ -23,6 +23,7 @@
 //---------------------------------------------------------------------------
 #include "MediaInfo/Text/File_N19.h"
 #include "MediaInfo/MediaInfo_Config_MediaInfo.h"
+#include "MediaInfo/TimeCode.h"
 #if MEDIAINFO_EVENTS
     #include "MediaInfo/MediaInfo_Events_Internal.h"
 #endif //MEDIAINFO_EVENTS
@@ -65,23 +66,66 @@ static const char* N19_CharacterCodeTable(int16u CCT)
 }
 
 //---------------------------------------------------------------------------
-static float64 N19_DiskFormatCode_FrameRate(int64u DFC)
+static string N19_CharacterCodeTable_CharSet(int16u CCT)
+{
+    switch (CCT)
+    {
+        case 0x3030 : return "ISO 6937-2";
+        case 0x3031 :
+        case 0x3032 :
+        case 0x3033 :
+        case 0x3034 : return "ISO 8859-"+to_string(CCT-0x3030+4);
+        default     : ;
+    }
+
+    auto CCT0=(char)(CCT>> 8);
+    auto CCT1=(char)(CCT    );
+    if (CCT0>='0' && CCT0<='9' && CCT1>='0' && CCT1<='9')
+    {
+        string CCT_Text="CCT ";
+        CCT_Text+=CCT0;
+        CCT_Text+=CCT1;
+        return CCT_Text;
+    }
+
+    return {};
+}
+
+//---------------------------------------------------------------------------
+static int8u N19_DiskFormatCode_FrameRate_Rounded(int64u DFC64)
+{
+    if ((DFC64&0xFFFFFF0000FFFFFF)!=0x53544C00002E3031LL)
+        return 99;
+    auto DFC=(int16u)(DFC64>>24);
+    auto DFC0=(int8u)(DFC>>8);
+    auto DFC1=(int8u)(DFC   );
+    if (DFC0<'0' || DFC0>'9' || DFC1<'0' || DFC1>'9')
+        return 99;
+    return (DFC0-'0')*10+DFC1-'0';
+}
+static float64 N19_DiskFormatCode_FrameRate_IsDropFrame(int8u DFC)
 {
     switch (DFC)
     {
-        case 0x53544C32332E3031LL : return (float64)24000/(float64)1001;
-        case 0x53544C32342E3031LL : return (float64)24;
-        case 0x53544C32352E3031LL : return (float64)25;
-        case 0x53544C32392E3031LL : return (float64)30000/(float64)1001;
-        case 0x53544C33302E3031LL : return (float64)30;
-        case 0x53544C34372E3031LL : return (float64)48000/(float64)1001;
-        case 0x53544C34382E3031LL : return (float64)48;
-        case 0x53544C35302E3031LL : return (float64)50;
-        case 0x53544C35392E3031LL : return (float64)60000/(float64)1001;
-        case 0x53544C36302E3031LL : return (float64)60;
-        default                   : return (float64) 0;
+        case 23 :
+        case 29 :
+        case 47 :
+        case 59 :
+                    return true;
+        default :   return false;
     }
 }
+static float64 N19_DiskFormatCode_FrameRate_FromRounded(int8u DFC)
+{
+    if (N19_DiskFormatCode_FrameRate_IsDropFrame(DFC))
+        return DFC*((float64)24000/(float64)1001);
+    else
+        return DFC;
+}
+static float64 N19_DiskFormatCode_FrameRate(int64u DFC64)
+{
+    return N19_DiskFormatCode_FrameRate_FromRounded(N19_DiskFormatCode_FrameRate_Rounded(DFC64));
+}
 
 //---------------------------------------------------------------------------
 static const char* N19_DisplayStandardCode(int8u DSC)
@@ -207,6 +251,151 @@ static const char* N19_LanguageCode(int16u LC)
     }
 }
 
+//---------------------------------------------------------------------------
+static string N19_YYMMDD_String(int64u V)
+{
+    auto V0=(int8u)(V>>40);
+    auto V1=(int8u)(V>>32);
+    auto V2=(int8u)(V>>24);
+    auto V3=(int8u)(V>>16);
+    auto V4=(int8u)(V>> 8);
+    auto V5=(int8u)(V    );
+    if (V0<'0' || V0>'9'
+     || V1<'0' || V1>'9'
+     || V2<'0' || V2>'1'
+     || V3<'0' || V3>'9'
+     || V4<'0' || V4>'3'
+     || V5<'0' || V5>'9')
+        return {};
+    string ToReturn;
+    if (V0<'8')
+    {
+        ToReturn+='2';
+        ToReturn+='0';
+    }
+    else
+    {
+        ToReturn+='1';
+        ToReturn+='9';
+    }
+    ToReturn+=V0;
+    ToReturn+=V1;
+    ToReturn+='-';
+    ToReturn+=V2;
+    ToReturn+=V3;
+    ToReturn+='-';
+    ToReturn+=V4;
+    ToReturn+=V5;
+    return ToReturn;
+}
+
+//---------------------------------------------------------------------------
+static TimeCode N19_HHMMSSFF_TC(int32u V, int8u FrameRate)
+{
+    auto HH=(int8u)(V>>24);
+    auto MM=(int8u)(V>>16);
+    auto SS=(int8u)(V>> 8);
+    auto FF=(int8u)(V    );
+    if (MM>=60
+     || SS>=61)
+        return {};
+    auto DropFrame=N19_DiskFormatCode_FrameRate_IsDropFrame(FrameRate);
+    auto FrameMax=FrameRate;
+    if (!DropFrame)
+        FrameMax--;
+    TimeCode TC(HH, MM, SS, FF, FrameMax, DropFrame);
+    return TC;
+}
+
+//---------------------------------------------------------------------------
+static TimeCode N19_HHMMSSFF_TC(int64u V, int8u FrameRate)
+{
+    auto V0=(int8u)(V>>56);
+    auto V1=(int8u)(V>>48);
+    auto V2=(int8u)(V>>40);
+    auto V3=(int8u)(V>>32);
+    auto V4=(int8u)(V>>24);
+    auto V5=(int8u)(V>>16);
+    auto V6=(int8u)(V>> 8);
+    auto V7=(int8u)(V    );
+    if (V0<'0' || V0>'9'
+     || V1<'0' || V1>'9'
+     || V2<'0' || V2>'5'
+     || V3<'0' || V3>'9'
+     || V4<'0' || V4>'6'
+     || V5<'0' || V5>'9'
+     || V6<'0' || V6>'9'
+     || V7<'0' || V7>'9')
+        return {};
+    auto DropFrame=N19_DiskFormatCode_FrameRate_IsDropFrame(FrameRate);
+    auto FrameMax=FrameRate;
+    if (!DropFrame)
+        FrameMax--;
+    TimeCode TC((V0-'0')*10+V1-'0',
+                (V2-'0')*10+V3-'0',
+                (V4-'0')*10+V5-'0',
+                (V6-'0')*10+V7-'0',
+                FrameMax,
+                DropFrame);
+    return TC;
+}
+
+//---------------------------------------------------------------------------
+static void CC2_Adapt(int16u& V)
+{
+    auto V0=(int8u)(V>>8);
+    auto V1=(int8u)(V   );
+    int16u Result;
+    if (V0>='0' && V0<='9')
+        Result=(V0-'0')*10;
+    else if (V0==' ')
+        Result=0;
+    else
+    {
+        V=0;
+        return;
+    }
+
+    if (V1>='0' && V1<='9')
+        Result+=V1-'0';
+    else if (V0!=' ')
+    {
+        V=0;
+        return;
+    }
+
+    V=Result;
+}
+
+//---------------------------------------------------------------------------
+static void CC8_Adapt(int64u& V, int8u Count)
+{
+    if (!Count)
+    {
+        V=0;
+        return;
+    }
+
+    int64u Result=0;
+    int8u  Offset=Count<<3;
+    do
+    {
+        Offset-=8;
+        auto V0=(int8u)(V>>Offset);
+        if (V0==' ')
+            break;
+        if (V0<'0' || V0>'9')
+        {
+            V=0;
+            return;
+        }
+        Result*=10;
+        Result+=V0-'0';
+    }
+    while (Offset);
+    V=Result;
+}
+
 //***************************************************************************
 // Constructor/Destructor
 //***************************************************************************
@@ -222,7 +411,6 @@ File_N19::File_N19()
     #endif //MEDIAINFO_EVENTS
 
     #if MEDIAINFO_DEMUX
-        TCP_Offset=0;
         Row_Values=NULL;
     #endif //MEDIAINFO_DEMUX
 }
@@ -276,104 +464,119 @@ void File_N19::FileHeader_Parse()
     Element_Name("General Subtitle Information");
 
     //Parsing
-    Ztring OPT, RD, TNS, MNC, MNR, CO, EN;
-    string TCP;
-    int16u LC;
+    Ztring OPT, OET, TPT, TET, TN, TCO, SLR, PUB, EN, ECD;
+    int64u DFC, CD, RD, TNB, TNS, TCP, TCF;
+    int32u CPN, CO;
+    int16u CCT, LC, RN, MNC, MNR;
     int8u  DSC, TCS;
-    Info_C3   (    CPN,                                         "CPN - Code Page Number"); Param_Info1(N19_CodePageNumber(CPN));
-    Get_C8    (    DFC,                                         "DFC - Disk Format Code"); Param_Info1C(N19_DiskFormatCode_FrameRate(DFC), N19_DiskFormatCode_FrameRate(DFC));
+    Get_C3    (    CPN,                                         "CPN - Code Page Number"); Param_Info1(N19_CodePageNumber(CPN));
+    Get_C8    (    DFC,                                         "DFC - Disk Format Code"); Param_Info1C(N19_DiskFormatCode_FrameRate_Rounded(DFC), N19_DiskFormatCode_FrameRate(DFC));
     Get_C1    (    DSC,                                         "DSC - Display Standard Code"); Param_Info1(N19_DisplayStandardCode(DSC));
     Get_C2    (    CCT,                                         "CCT - Character Code Table number"); Param_Info1(N19_CharacterCodeTable(CCT));
-    Get_C2    (    LC,                                          "LC - Language Code"); Param_Info1(N19_LanguageCode(LC));
+    Get_C2    (    LC ,                                         "LC - Language Code"); Param_Info1(N19_LanguageCode(LC));
     Get_Local (32, OPT,                                         "OPT - Original Programme Title");
-    Skip_Local(32,                                              "OET - Original Episode Title");
-    Skip_Local(32,                                              "TPT - Translated Programme");
-    Skip_Local(32,                                              "TET - Translated Episode");
-    Skip_Local(32,                                              "TN - Translator's Name");
-    Skip_Local(32,                                              "TCD - Translator's Contact Details");
-    Skip_Local(16,                                              "SLR - Subtitle List Reference Code");
-    Skip_Local( 6,                                              "CD - Creation Date");
-    Get_Local ( 6, RD,                                          "RD - Revision Date");
-    Skip_C2   (                                                 "RN - Revision number");
-    Skip_C5   (                                                 "TNB - Total Number of Text and Timing Information (TTI) blocks");
-    Get_Local ( 5, TNS,                                         "TNS - Total Number of Subtitles");
+    Get_Local (32, OET,                                         "OET - Original Episode Title");
+    Get_Local (32, TPT,                                         "TPT - Translated Programme");
+    Get_Local (32, TET,                                         "TET - Translated Episode");
+    Get_Local (32, TN ,                                         "TN - Translator's Name");
+    Get_Local (32, TCO,                                         "TCD - Translator's Contact Details");
+    Get_Local (16, SLR,                                         "SLR - Subtitle List Reference Code");
+    Get_C6    (    CD ,                                         "CD - Creation Date");
+    Get_C6    (    RD ,                                         "RD - Revision Date");
+    Get_C2    (    RN ,                                         "RN - Revision number");
+    Get_C5    (    TNB,                                         "TNB - Total Number of Text and Timing Information (TTI) blocks");
+    Get_C5    (    TNS,                                         "TNS - Total Number of Subtitles");
     Skip_C3   (                                                 "TNG - Total Number of Subtitle Groups");
-    Get_Local ( 2, MNC,                                         "MNC - Maximum Number of Displayable Characters in any text row");
-    Get_Local ( 2, MNR,                                         "MNR - Maximum Number of Displayable Rows");
+    Get_C2    (    MNC,                                         "MNC - Maximum Number of Displayable Characters in any text row");
+    Get_C2    (    MNR,                                         "MNR - Maximum Number of Displayable Rows");
     Get_C1    (    TCS,                                         "TCS - Time Code: Status");
-    Get_String( 8, TCP,                                         "TCP - Time Code: Start-of-Programme");
-    Skip_Local( 8,                                              "TCF - Time Code: First In-Cue");
+    Get_C8    (    TCP,                                         "TCP - Time Code: Start-of-Programme");
+    Get_C8    (    TCF,                                         "TCF - Time Code: First In-Cue");
     Skip_C1   (                                                 "TND - Total Number of Disks");
     Skip_C1   (                                                 "DSN - Disk Sequence Number");
-    Get_Local ( 3, CO,                                          "CO - Country of Origin");
-    Skip_Local(32,                                              "PUB - Publisher");
-    Get_Local (32, EN,                                          "EN - Editor's Name");
-    Skip_Local(32,                                              "ECD - Editor's Contact Details");
+    Get_C3    (    CO ,                                         "CO - Country of Origin");
+    Get_Local (32, PUB,                                         "PUB - Publisher");
+    Get_Local (32, EN ,                                         "EN - Editor's Name");
+    Get_Local (32, ECD,                                         "ECD - Editor's Contact Details");
     Skip_XX(75,                                                 "Spare Bytes");
     Skip_XX(576,                                                "UDA - User-Defined Area");
 
     FILLING_BEGIN();
+        FrameRate=N19_DiskFormatCode_FrameRate_Rounded(DFC);
+
         Accept("N19");
 
         Fill(Stream_General, 0, General_Format, "N19");
-        Fill(Stream_General, 0, General_Title, OPT);
-        RD.insert(0, __T("20"));
-        RD.insert(4, __T("-"));
-        RD.insert(7, __T("-"));
-        Fill(Stream_General, 0, General_Recorded_Date, RD);
-        Fill(Stream_General, 0, General_Country, Ztring(CO).MakeLowerCase());
-        EN.Trim();
-        Fill(Stream_General, 0, General_DistributedBy, EN);
+        Fill(Stream_General, 0, General_Title, OPT.Trim());
+        if (OPT!=OET.Trim())
+            Fill(Stream_General, 0, General_Title, OET);
+        if (RN!=0x2030 && RN!=0x3030)
+        {
+            auto RN0=(char)(RN>> 8);
+            auto RN1=(char)(RN);
+            if ((RN0==' ' || RN0 >= '0' && RN0<'9') && RN1>='0' && RN1<'9')
+            {
+                string RN_Text;
+                if (RN0!=' ' && RN0!='0')
+                    RN_Text+=RN0;
+                RN_Text+=RN1;
+                Fill(Stream_General, 0, "Revision", RN_Text);
+            }
+        }
+        Fill(Stream_General, 0, General_EncodedBy, TN.Trim());
+        Fill(Stream_General, 0, General_EncodedBy, TCO.Trim());
+        Fill(Stream_General, 0, General_Encoded_Date, N19_YYMMDD_String(CD));
+        Fill(Stream_General, 0, General_Tagged_Date, N19_YYMMDD_String(RD));
+        Fill(Stream_General, 0, General_CatalogNumber, SLR.Trim());
+        Fill(Stream_General, 0, General_Country, Ztring().From_CC3(CO).MakeUpperCase());
+        Fill(Stream_General, 0, General_EditedBy, EN.Trim());
+        if (EN!=ECD.Trim())
+            Fill(Stream_General, 0, General_EditedBy, ECD);
+        Fill(Stream_General, 0, General_Publisher, PUB.Trim());
+        auto CPN0=(char)(CPN>>16);
+        auto CPN1=(char)(CPN>> 8);
+        auto CPN2=(char)(CPN    );
+        if (CPN0>='0' && CPN0<'9' && CPN1>='0' && CPN1<'9' && CPN2>='0' && CPN2<'9')
+        {
+            string CPN_Text="CP "+Ztring().From_CC3(CPN).To_UTF8();
+            Fill(Stream_General, 0, "CharacterSet", CPN_Text.c_str());
+        }
 
         Stream_Prepare(Stream_Text);
         Fill(Stream_Text, 0, Text_Format, "N19");
-        if (N19_DiskFormatCode_FrameRate(DFC))
+        if (FrameRate)
         {
-            Fill(Stream_Text, 0, "FrameRate", N19_DiskFormatCode_FrameRate(DFC));
-            if (TCS==0x31 && TCP.size()==8
-             && TCP[0]>='0' && TCP[0]<='9'
-             && TCP[1]>='0' && TCP[1]<='9'
-             && TCP[2]>='0' && TCP[2]<='6'
-             && TCP[3]>='0' && TCP[3]<='9'
-             && TCP[4]>='0' && TCP[4]<='6'
-             && TCP[5]>='0' && TCP[5]<='9'
-             && TCP[6]>='0' && TCP[6]<='2'
-             && TCP[7]>='0' && TCP[7]<='9')
-            {
-                int64u Delay=0;
-                Delay+=(((int32u)TCP[0])-'0')*10*60*60*1000;
-                Delay+=(((int32u)TCP[1])-'0')*   60*60*1000;
-                Delay+=(((int32u)TCP[2])-'0')*   10*60*1000;
-                Delay+=(((int32u)TCP[3])-'0')*      60*1000;
-                Delay+=(((int32u)TCP[4])-'0')*      10*1000;
-                Delay+=(((int32u)TCP[5])-'0')*         1000;
-                int8u Frames=0;
-                Frames+=(((int8u)TCP[6])-'0')*10;
-                Frames+=(((int8u)TCP[7])-'0');
-                if (N19_DiskFormatCode_FrameRate(DFC))
-                    Delay+=float64_int64s(Frames*1000/N19_DiskFormatCode_FrameRate(DFC));
-                //Fill(Stream_Text, 0, Text_Delay, Delay); //TODO is 0???
-                TCP.insert(TCP.begin()+2, ':');
-                TCP.insert(TCP.begin()+5, ':');
-                TCP.insert(TCP.begin()+8, ':');
-                //Fill(Stream_Text, 0, "Delay/String4", TCP);
-                Fill(Stream_Text, 0, "TimeCode_First", TCP);
-
-#if MEDIAINFO_DEMUX
-                TCP_Offset=Delay;
-#endif
-            }
+            Fill(Stream_General, 0, General_FrameRate, N19_DiskFormatCode_FrameRate_FromRounded(FrameRate));
+            Fill(Stream_Text, 0, Text_FrameRate, N19_DiskFormatCode_FrameRate_FromRounded(FrameRate));
+            if (TCS==0x31)
+                Fill(Stream_General, 0, General_Duration_Start, N19_HHMMSSFF_TC(TCP, FrameRate).ToMilliseconds());
         }
-        Fill(Stream_Text, 0, Text_Width, MNC.To_int32u());
-        Fill(Stream_Text, 0, Text_Height, MNR.To_int32u());
+        CC2_Adapt(MNC);
+        CC2_Adapt(MNR);
+        CC8_Adapt(TNS, 5);
+        if (MNC)
+            Fill(Stream_Text, 0, Text_Width, MNC);
+        if (MNR)
+            Fill(Stream_Text, 0, Text_Height, MNR);
         Fill(Stream_Text, 0, Text_Language, N19_LanguageCode(LC));
+        Fill(Stream_Text, 0, Text_Events_Total, TNS);
+        Fill(Stream_Text, 0, "CharacterSet", N19_CharacterCodeTable_CharSet(CCT));
 
         //Init
-        FirstFrame_TCI=(int64u)-1;
+        TCI_FirstFrame=(int32u)-1;
+        LineCount=0;
+        LineCount_Max=0;
+        TotalLines=0;
+        Line_HasContent=false;
+        auto CCT_Sav=CCT;
+        CC2_Adapt(CCT);
+        if (CCT || CCT_Sav==0x3030)
+            CharSet=(int8u)CCT;
+        else
+            CharSet=(int8u)-1;
         #if MEDIAINFO_DEMUX
-            Frame_Count=0;
-            TCO_Latest=(int64u)-1;
-            Row_Max=MNR.To_int8u();
+            TCO_Previous=(int32u)-1;
+            Row_Max=(int8u)MNC;
             if ((DSC=='1' || DSC=='2') && Row_Max<23)
             {
                 Row_Max=23;
@@ -381,7 +584,7 @@ void File_N19::FileHeader_Parse()
             }
             else
                 IsTeletext=false;
-            Column_Max=MNC.To_int8u();
+            Column_Max=(int8u)MNR;
             Row_Values=new wchar_t*[Row_Max];
             for (int8u Row_Pos=0; Row_Pos<Row_Max; ++Row_Pos)
             {
@@ -389,6 +592,10 @@ void File_N19::FileHeader_Parse()
                 Row_Values[Row_Pos][Column_Max]=__T('\0');
             }
         #endif //MEDIAINFO_DEMUX
+        if (TCS!=0x31)
+            Finish();
+    FILLING_ELSE();
+        Reject();
     FILLING_END();
 }
 
@@ -401,7 +608,7 @@ void File_N19::FileHeader_Parse()
 size_t File_N19::Read_Buffer_Seek (size_t Method, int64u Value, int64u ID)
 {
     #if MEDIAINFO_DEMUX
-        TCO_Latest=(int64u)-1;
+        TCO_Previous=(int32u)-1;
     #endif //MEDIAINFO_DEMUX
 
     GoTo(0x400);
@@ -428,23 +635,17 @@ void File_N19::Data_Parse()
     //Parsing
     Ztring TF;
     int32u TCI, TCO;
-    int8u  VP, JC;
+    int8u  EBN, VP, JC;
     Skip_B1   (                                                 "SGN - Subtitle Group Number");
     Skip_B2   (                                                 "SN - Subtitle Number");
-    Skip_B1   (                                                 "EBN - Extension Block Number");
+    Get_B1    (EBN,                                             "EBN - Extension Block Number");
     Skip_B1   (                                                 "CS - Cumulative Status");
     Get_B4    (TCI,                                             "TCI - Time Code In");
-    TCI=((TCI>>24)&0xFF)*60*60*1000
-      + ((TCI>>16)&0xFF)   *60*1000
-      + ((TCI>>8 )&0xFF)      *1000
-      + (N19_DiskFormatCode_FrameRate(DFC)?((int32u)float64_int64s((TCI     &0xFF)      *1000/N19_DiskFormatCode_FrameRate(DFC))):0);
-    Param_Info1(Ztring().Duration_From_Milliseconds((int64u)TCI));
+    auto TCI_TC=N19_HHMMSSFF_TC(TCI, FrameRate);
+    Param_Info1(TCI_TC.ToString());
     Get_B4    (TCO,                                             "TCO - Time Code Out");
-    TCO=((TCO>>24)&0xFF)*60*60*1000
-      + ((TCO>>16)&0xFF)   *60*1000
-      + ((TCO>>8 )&0xFF)      *1000
-      + (N19_DiskFormatCode_FrameRate(DFC)?((int32u)float64_int64s((TCO     &0xFF)      *1000/N19_DiskFormatCode_FrameRate(DFC))):0);
-    Param_Info1(Ztring().Duration_From_Milliseconds((int64u)TCO));
+    auto TCO_TC=N19_HHMMSSFF_TC(TCO, FrameRate);
+    Param_Info1(TCO_TC.ToString());
     Get_B1    (VP,                                              "VP - Vertical Position");
     if (VP 
 #if MEDIAINFO_DEMUX
@@ -454,19 +655,55 @@ void File_N19::Data_Parse()
         VP--; //1-Based
     Get_B1    (JC,                                              "JC - Justification Code");
     Skip_B1   (                                                 "CF - Comment Flag");
-    switch (CCT)
+    switch (CharSet)
     {
-        case 0x3030 :   //Latin ISO 6937-2
+        case 0 :        //Latin ISO 6937-2
                         Get_ISO_6937_2(112, TF,                 "TF - Text Field");
                         break;
-        case 0x3031 :   //Latin ISO 8859-5
+        case 1 :        //Latin ISO 8859-5
                         Get_ISO_8859_5(112, TF,                 "TF - Text Field");
                         break;
         default:
                         //Not yet supported, basic default
                         Get_ISO_8859_1(112, TF,                 "TF - Text Field");
     }
-    #if MEDIAINFO_TRACE
+    //Count
+    TF.TrimRight(0x8F);
+    if (EBN<0xF0 || EBN==0xFF)
+    {
+        for (auto Value : TF)
+        {
+            if ((Value>=0x20 && Value<0x7F) || Value>=0xA0)
+                Line_HasContent=true;
+            else
+            {
+                switch (Value)
+                {
+                    case 0x8A:  //EOL
+                                if (Line_HasContent)
+                                {
+                                    LineCount++;
+                                    Line_HasContent=false;
+                                }
+                                break;
+                    default  :  ;
+                }
+            }
+        }
+        if (EBN==0xFF)
+        {
+            if (Line_HasContent)
+            {
+                LineCount++;
+                Line_HasContent=false;
+            }
+            if (LineCount_Max<LineCount)
+                LineCount_Max=LineCount;
+            TotalLines+=LineCount;
+            LineCount=0;
+        }
+    }
+#if MEDIAINFO_TRACE
         for (size_t i = 0; i < TF.size(); ++i)
             switch (TF[i])
             {
@@ -478,12 +715,9 @@ void File_N19::Data_Parse()
                                     TF.insert(++i, 1, EOL[j++]);
                             };
                             break;
-                case 0x8F:  // Padding
-                            TF.erase(i--, 1);
-                            break;
                 default:
                     if ( TF[i]< 0x20
-                     || (TF[i]>=0x80 && TF[i]<0xA0))
+                     || (TF[i]>=0x7F && TF[i]<0xA0))
                         TF.erase(i--, 1);
             }
         Param_Info1(TF);
@@ -502,12 +736,9 @@ void File_N19::Data_Parse()
                                         TF.insert(++i, 1, EOL[j++]);
                                 };
                                 break;
-                    case 0x8F:  // Padding
-                                TF.erase(i--, 1);
-                                break;
                     default:
                         if ( TF[i]< 0x20
-                         || (TF[i]>=0x80 && TF[i]<0xA0))
+                         || (TF[i]>=0x7F && TF[i]<0xA0))
                             TF.erase(i--, 1);
                 }
 
@@ -518,12 +749,12 @@ void File_N19::Data_Parse()
                 for (int8u Column_Pos=0; Column_Pos<Column_Max; ++Column_Pos)
                     Row_Values[Row_Pos][Column_Pos]=__T(' ');
 
-            if (TCO_Latest!=(int64u)-1 && TCI!=TCO_Latest)
+            if (TCO_Previous!=(int32u)-1 && TCI!=TCO_Previous)
             {
                 EVENT_BEGIN (Global, SimpleText, 0)
-                    Event.DTS=((int64u)(TCO_Latest))*1000000; // "-TCP_Offset" removed for the moment. TODO: find a way for when TCP_Offset should be removed and when it should not
+                    Event.DTS=((int64u)N19_HHMMSSFF_TC(TCO_Previous, FrameRate).ToMilliseconds())*1000000; // "-TCP" removed for the moment. TODO: find a way for when TCP should be removed and when it should not
                     Event.PTS=Event.DTS;
-                    Event.DUR=((int64u)(TCI-TCO_Latest))*1000000;
+                    Event.DUR=((int64u)(N19_HHMMSSFF_TC(TCI, FrameRate)-N19_HHMMSSFF_TC(TCO_Previous, FrameRate)).ToMilliseconds())*1000000;
                     Event.Content=L"";
                     Event.Flags=0;
                     Event.MuxingMode=(int8u)-1;
@@ -596,9 +827,9 @@ void File_N19::Data_Parse()
             }
 
             EVENT_BEGIN (Global, SimpleText, 0)
-                Event.DTS=((int64u)(TCI))*1000000; // "-TCP_Offset" removed for the moment. TODO: find a way for when TCP_Offset should be removed and when it should not
+                Event.DTS=((int64u)N19_HHMMSSFF_TC(TCI, FrameRate).ToMilliseconds())*1000000; // "-TCP" removed for the moment. TODO: find a way for when TCP should be removed and when it should not
                 Event.PTS=Event.DTS;
-                Event.DUR=((int64u)(TCO-TCI))*1000000;
+                Event.DUR=((int64u)(N19_HHMMSSFF_TC(TCO, FrameRate)-N19_HHMMSSFF_TC(TCI, FrameRate)).ToMilliseconds())*1000000;
                 Event.Content=TF.To_Unicode().c_str();
                 Event.Flags=0;
                 Event.MuxingMode=(int8u)-1;
@@ -610,20 +841,28 @@ void File_N19::Data_Parse()
             EVENT_END   ()
 
             Frame_Count++;
-            TCO_Latest=TCO;
+            TCO_Previous=TCO;
         #endif //MEDIAINFO_DEMUX
 
-        if (FirstFrame_TCI==(int64u)-1)
+        if (TCI_FirstFrame==(int32u)-1)
         {
-            FirstFrame_TCI=TCI;
-            Fill(Stream_Text, 0, Text_Delay, TCI);
+            TCI_FirstFrame=TCI;
+            auto Begin=N19_HHMMSSFF_TC(TCI, FrameRate);
+            Fill(Stream_Text, 0, Text_Duration_Start, Begin.ToMilliseconds());
+            Fill(Stream_Text, 0, Text_TimeCode_FirstFrame, Begin.ToString());
+            Fill(Stream_Text, 0, Text_Delay, Begin.ToMilliseconds());
             Fill(Stream_Text, 0, Text_Delay_Source, "Container");
         }
         if (File_Offset+Buffer_Offset+Element_Size+128>File_Size)
         {
-            Fill(Stream_Text, 0, Text_Duration, TCO-FirstFrame_TCI);
+            auto End=N19_HHMMSSFF_TC(TCO, FrameRate);
+            Fill(Stream_Text, 0, Text_Duration, (End-N19_HHMMSSFF_TC(TCI_FirstFrame, FrameRate)).ToMilliseconds());
+            Fill(Stream_Text, 0, Text_Duration_End, End.ToMilliseconds());
+            Fill(Stream_Text, 0, Text_TimeCode_LastFrame, (End-1).ToString());
+            Fill(Stream_Text, 0, Text_Lines_Count, TotalLines);
+            Fill(Stream_Text, 0, Text_Lines_MaxCountPerEvent, LineCount_Max);
         }
-        else if (Config->ParseSpeed<1.0)
+        else if (Config->ParseSpeed<0.5)
             //Jumping
             GoToFromEnd(128, "N19");
     FILLING_END();
